@@ -63,7 +63,7 @@ def is_port_installed():
     except OSError:
         return False
     
-def port_detect(packages, exec_fn=None):
+def port_detect(pkgs, exec_fn=None):
     ret_list = []
     if not is_port_installed():
         return ret_list
@@ -112,9 +112,12 @@ def brew_detect(formulas, exec_fn=None):
     ret_list = []
     std_out = exec_fn(['brew', 'list'])
     # preserve order
+    clean_formulas = []
+    for f in formulas:
+        clean_formulas.append(f.split('/')[-1])
     for f in std_out.split():
-        if f in formulas:
-            ret_list.append(f)
+        if f in clean_formulas:
+            ret_list.append(formulas[clean_formulas.index(f)])
     return ret_list
 
 class HomebrewInstaller(PackageManagerInstaller):
@@ -130,7 +133,11 @@ class HomebrewInstaller(PackageManagerInstaller):
         packages = self.get_packages_to_install(resolved, reinstall=reinstall)
         # interactive switch doesn't matter
         if reinstall:
-            return [['brew', 'install', '--force', p] for p in packages]
+            commands = []
+            for p in packages:
+                commands.append(['brew', 'uninstall', '--force', p])
+                commands.append(['brew', 'install', p])
+            return commands
         else:
             return [['brew', 'install', p] for p in packages]
 
